package com.sooka.sponest.monitor.aideviceevent.mapper;

import com.sooka.sponest.monitor.aideviceevent.domain.CenterdataTAideviceevent;

import java.util.List;

/**
 * AI对应事件Mapper接口
 *
 * @author yy
 * @date 2022-09-01
 */
public interface CenterdataTAideviceeventMapper
{
    /**
     * 查询AI对应事件
     *
     * @param id AI对应事件主键
     * @return AI对应事件
     */
     CenterdataTAideviceevent selectCenterdataTAideviceeventById(String id);

    /**
     * 查询AI对应事件列表
     *
     * @param centerdataTAideviceevent AI对应事件
     * @return AI对应事件集合
     */
     List<CenterdataTAideviceevent> selectCenterdataTAideviceeventList(CenterdataTAideviceevent centerdataTAideviceevent);

    /**
     * 新增AI对应事件
     *
     * @param centerdataTAideviceevent AI对应事件
     * @return 结果
     */
     int insertCenterdataTAideviceevent(CenterdataTAideviceevent centerdataTAideviceevent);

    /**
     * 修改AI对应事件
     *
     * @param centerdataTAideviceevent AI对应事件
     * @return 结果
     */
     int updateCenterdataTAideviceevent(CenterdataTAideviceevent centerdataTAideviceevent);

    /**
     * 删除AI对应事件
     *
     * @param id AI对应事件主键
     * @return 结果
     */
     int deleteCenterdataTAideviceeventById(String id);

    /**
     * 批量删除AI对应事件
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteCenterdataTAideviceeventByIds(String[] ids);
     int deleteCenterdataTAideviceeventByCameraIds(String[] ids);


    //根据设备code查询
     List<CenterdataTAideviceevent> selectEventTypeByDeviceCode(String deviceCode);
}
